<?php


namespace App\Http\Controllers\Api;
use App\Http\Params\ProblemParam;
use App\Models\User;
use App\Models\UserExtModel;
use App\Models\UserInfoModel;
use App\Models\VipModel;
use App\Services\UserService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class UserController extends Controller
{
    protected $userService;

    public function __construct(){
        $this->userService = new UserService();
    }

    /**
     * 设置密码
     */
    public function setpass(Request $request){
        $validator = Validator::make($request->all(), [
            'password' => 'required|string',
        ],[
            'password.required'=>"密码必须",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $user = auth('api')->user();
        $user->password = $request->password;
        if($user->save()){
            return response()->json(['message'=>"设置成功"]);
        }else{
            return $this->response->errorForbidden("设置失败");
        }
    }

    /**
     * 选择性别
     */
    public function checksex(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'sex' => 'required'
        ], [
            'mobile.required'=>"性别必须",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        //dd($user);
        $user->sex = $request->sex;
        if (!$user->save()) {
            return $this->response->errorForbidden('设置性别失败');
        }
        return response()->json(['message'=>"设置成功"]);
    }

    /**
     * 设置资料（初次登录）
     */
    public function setinfo(Request $request){
        $user = auth('api')->user();

        $validator = Validator::make($request->all(), [
            'nickname' => 'required|between:2,8',
            'birthday' => 'required',
            'avatar' => 'required',
        ], [
            'nickname.required'=>"昵称不能为空",
            'nickname.between'=>"昵称长度必须在2~8之间",
            'birthday.required'=>"生日不能为空",
            'avatar.required'=>"头像不能为空",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }

        if(UserInfoModel::where(['nickname'=>$request->nickname])->where('user_id', '!=' , $user->id)->first()){
            return $this->response->errorForbidden('昵称已被使用');
        }
        //邀请码设置
        $pid = 0;
        if(isset($request->ycode) && $request->ycode!=""){
            if(!$puser = User::where(['ycode'=>$request->ycode])->first()){
                return $this->response->errorForbidden("邀请码不存在");
            }
            $pid = $puser->id;
        }

        DB::beginTransaction();
        try {
            UserInfoModel::firstOrCreate([
                'user_id' => $user->id,
                'avatar' =>$request->avatar,
                'nickname' =>$request->nickname,
                'birthday' =>$request->birthday,
            ]);
            if($pid!=0){
               $user->pid = $pid;
               $user->save();
            }
            DB::commit();
        } catch (\Exception $e) {
            DB::rollBack();
            return $this->response->errorForbidden($e->getMessage());
        }
        return response()->json(['message'=>"设置成功"]);
    }

    /**
     * 获取个人资料
     */
    public function getinfo(){
        $user = auth('api')->user();
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();
        return response()->json($userinfo);
    }

    /**
     * 获取个人更多介绍
     */
    public function getext(){
        $user = auth('api')->user();
        $userext = UserExtModel::firstOrCreate([
            "user_id"=>$user->id
        ]);
        return response()->json($userext);
    }

    /**
     * 修改个人资料
     */
    public function updateinfo(Request $request){
        $user = auth('api')->user();
        $validator = Validator::make($request->all(), [
            'nickname' => 'required',
            'height' => 'integer',
            'weight' => 'integer',
        ], [
            'nickname.required'=>"昵称必须",
            'height.integer'=>"身高为整数",
            'weight.integer'=>"体重为整数",
        ]);
        if ($validator->fails()) {
            return $this->response()->errorForbidden($validator->messages()->first());
        }
        $userinfo = UserInfoModel::where('user_id', $user->id)->first();
        if($request->nickname!=$userinfo->nickname){
            if(UserInfoModel::where(['nickname'=>$request->nickname])->first()){
                return $this->response->errorForbidden('昵称已被使用');
            }
        }
        if(UserInfoModel::where('user_id', $user->id)->update($request->input())){
            return response()->json(['message'=>"修改成功"]);
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 修改个人更多介绍
     */
    public function updateext(Request $request){
        $user = auth('api')->user();
        if(UserExtModel::where('user_id', $user->id)->update($request->input())){

            return response()->json(['message'=>"修改成功"]);
        }else{
            return $this->response->errorForbidden("修改失败");
        }
    }

    /**
     * 获取VIP
     */
    public function get_vip(){
        try {
            $res = VipModel::query()->orderBy('id','asc')->get();
            foreach ($res as $k=>$v){
                $res[$k]['rights'] = json_decode($v['rights'],true);
            }
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }

    /**
     * 购买/续费vip
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function buy_vip(Request $request){
        try {
            $user = auth('api')->user();
            $param['id'] = $request->id;  //vip id
            $param['user_id'] = $user->id;
            $param['payment'] = $request->payment; //支付方式 1微信  2支付宝
            $res = $this->userService->buy_vip($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }


    /**
     * 问题反馈
     * @param Request $request
     * @return \Dingo\Api\Http\Response|void
     */
    public function problem(Request $request){
        try {
            $user = auth('api')->user();
            $param = new ProblemParam();
            $param->user_id = $user->id;
            $param->content = $request->post('content');
            $param->img_url = $request->post('img_url');
            $param->status = 0;
            $this->userService->problem($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json(['message'=>"提交成功"]);
    }

    /**
     * 看过我
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|void
     */
    public function looked_me(Request $request){
        try {
            $user = auth('api')->user();
            $param['user_id'] = $user->id;
            $res =$this->userService->looked_me($param);
        }catch (\Exception $exception){
            return $this->response->errorForbidden($exception->getMessage());
        }
        return response()->json($res);
    }


}
