<?php

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/
$api = app('Dingo\Api\Routing\Router');

$api->version('v1', [
    'namespace' => 'App\Http\Controllers\Api',
    'middleware' => ['serializer:array','cors','activity_log','bindings']
], function ($api) {

    $api->group([
        'middleware' => 'api.throttle',
        'limit' => config('api.rate_limits.access.limit'),
        'expires' => config('api.rate_limits.access.expires')
    ], function ($api) {

        /*
        |--------------------------------------------------------------
        |  登录相关
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'login'], function ($api) {
            $api->post('/login_by_mobile', 'AuthorizationsController@login_by_mobile')->name('login.mobile');
            $api->post('/login_by_password', 'AuthorizationsController@login_by_password')->name('login.password');
            $api->post('/forget_password', 'AuthorizationsController@forget_password')->name('login.forget');
            $api->post('/register', 'AuthorizationsController@register')->name('login.register');
            $api->get('/xieyi', 'AuthorizationsController@xieyi')->name('login.xieyi');
        });

        /*
        |--------------------------------------------------------------
        |  获取oss上传配置
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'upload-config'], function ($api) {
            $api->get('/config', 'UploadConfigController@config')->name('upload.config');
        });

        /*
        |--------------------------------------------------------------
        |  发送短信验证码
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'sms'], function ($api) {
            $api->get('/send', 'SmsController@send')->name('sms.send');
        });



    });
    //需要 token 验证的接口
    $api->group(['middleware' => 'api.auth'], function ($api) {
        /*
        |--------------------------------------------------------------
        |  用户信息相关
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'user'], function ($api) {
            //设置性别
            $api->post('/checksex', 'UserController@checksex')->name('user.checksex');
            //设置资料（初次注册进入时）
            $api->post('/setinfo', 'UserController@setinfo')->name('user.setinfo');
            $api->post('/setpass', 'UserController@setpass')->name('user.setpass');
            $api->get('/getinfo', 'UserController@getinfo')->name('user.getinfo');
            $api->get('/getext', 'UserController@getext')->name('user.getext');
            $api->post('/updateinfo', 'UserController@updateinfo')->name('user.updateinfo');
            $api->post('/updateext', 'UserController@updateext')->name('user.updateext');
            $api->post('/problem', 'UserController@problem')->name('user.problem');
            $api->post('/looked_me', 'UserController@looked_me')->name('user.looked_me');
            $api->get('/get_vip', 'UserController@get_vip')->name('user.get_vip');
            $api->post('/buy_vip', 'UserController@buy_vip')->name('user.buy_vip');
        });

        /*
        |--------------------------------------------------------------
        |  动态相关
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'dynamic'], function ($api) {
            $api->post('/get_tag_list', 'DynamicController@get_tag_list')->name('dynamic.get_tag_list');
            $api->post('/release', 'DynamicController@release')->name('dynamic.release');
            $api->post('/get_list', 'DynamicController@get_list')->name('dynamic.get_list');
            $api->post('/my_list', 'DynamicController@my_list')->name('dynamic.my_list');
            $api->post('/zan', 'DynamicController@zan')->name('dynamic.zan');
            $api->post('/del', 'DynamicController@del')->name('dynamic.del');
            $api->post('/report', 'DynamicController@report')->name('dynamic.report');
            $api->get('/dynamic_info', 'DynamicController@dynamic_info')->name('dynamic.dynamic_info');
        });


        /*
        |--------------------------------------------------------------
        |  消息相关
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'notice'], function ($api) {
            $api->post('/get_notice_list', 'NoticeController@get_notice_list')->name('notice.get_notice_list');
            $api->post('/get_like_list', 'NoticeController@get_like_list')->name('notice.get_like_list');
            $api->post('/get_zan_list', 'NoticeController@get_zan_list')->name('notice.get_zan_list');
            $api->post('/get_system_message', 'NoticeController@get_system_message')->name('notice.get_system_message');
        });

        /*
        |--------------------------------------------------------------
        |  聊天相关
        |--------------------------------------------------------------
        */
        $api->group(['prefix' => 'chat'], function ($api) {
            $api->post('/add_friend', 'ChatController@add_friend')->name('chat.add_friend');
            $api->post('/get_friend', 'ChatController@get_friend')->name('chat.get_friend');
        });


        /*
        |--------------------------------------------------------------
        |  文件上传
        |--------------------------------------------------------------
        */
        $api->post('/upload', 'UploadController@upload')->name('upload');

        /*
        |--------------------------------------------------------------
        |  退出登录
        |--------------------------------------------------------------
        */
        $api->put('/logout', 'AuthorizationsController@logout')->name('logout');
    });

    /*
        |--------------------------------------------------------------
        |  支付回调
        |--------------------------------------------------------------
        */
    $api->any('/wx_notify', 'PayNotifyController@wx_notify')->name('wx_notify');
    $api->any('/ali_notify', 'PayNotifyController@ali_notify')->name('ali_notify');


});
